==> trytond_dashboard-2.0.1.tar.gz: trytond_dashboard-2.0.1/__tryton__.py <==
# -*- coding: utf-8 -*-
#This file is part of Tryton.  The COPYRIGHT file at the top level of
#this repository contains the full copyright notices and license terms.
{
    'name': 'Dashboard',
    'name_bg_BG': 'Табло',
    'name_de_DE': 'Dashboard',
    'name_es_CO': 'Escritorio',
    'name_es_ES': 'Escritorio',
    'name_fr_FR': 'Tableau de bord',
    'name_nl_NL': 'Prikbord',
    'name_ru_RU': 'Информационная панель',
    'version': '2.0.1',
    'author': 'B2CK',
    'email': 'info@b2ck.com',
    'website': 'http://www.tryton.org/',
    'description': '''Dashboard:
    - Allow to create a personalized dashboard.
''',
    'description_bg_BG': '''Табло:
    - Позволява създаване на перосонализирани табла.
''',
    'description_de_DE': '''Dashboard:
    - Ermöglicht die Einrichtung einer personalisierten Startseite.
''',
    'description_es_CO': '''Escritorio:
    - Permite la creación de una página de inicio personalizada.
''',
    'description_es_ES': '''Escritorio:
    - Permite la creación de una página de inicio personalizada.
''',
    'description_fr_FR': '''Tableau de bord
    - Permet de créer un tableau de bord personalisé.
''',
    'description_nl_NL': '''Prikbord:
    - Maakt een persoonlijk prikbord mogelijk.
''',
    'description_ru_RU': '''Информационная панель:
    - позволяет создавать персональные панели.
''',
    'depends': [
        'ir',
        'res',
    ],
    'xml': [
        'dashboard.xml',
        'res.xml',
        'ir.xml',
    ],
    'translation': [
        'bg_BG.csv',
        'de_DE.csv',
        'es_CO.csv',
        'es_ES.csv',
        'fr_FR.csv',
        'nl_NL.csv',
        'ru_RU.csv',
    ],
}

==> trytond_dashboard-2.4.0.tar.gz: trytond_dashboard-2.4.0/__tryton__.py <==
# -*- coding: utf-8 -*-
#This file is part of Tryton.  The COPYRIGHT file at the top level of
#this repository contains the full copyright notices and license terms.
{
    'name': 'Dashboard',
    'name_bg_BG': 'Табло',
    'name_ca_ES': 'Escriptori',
    'name_de_DE': 'Dashboard',
    'name_es_AR': 'Tablero',
    'name_es_CO': 'Escritorio',
    'name_es_ES': 'Escritorio',
    'name_fr_FR': 'Tableau de bord',
    'name_nl_NL': 'Prikbord',
    'name_ru_RU': 'Информационная панель',
    'version': '2.4.0',
    'author': 'B2CK',
    'email': 'info@b2ck.com',
    'website': 'http://www.tryton.org/',
    'description': '''Dashboard:
    - Allow to create a personalized dashboard.
''',
    'description_bg_BG': '''Табло:
    - Позволява създаване на перосонализирани табла.
''',
    'description_ca_ES': '''Escriptori:
    - Permet la creació d'una pàgina d'inici personalitzada per usuari.
''',
    'description_de_DE': '''Dashboard:
    - Ermöglicht die Einrichtung einer personalisierten Startseite.
''',
    'description_es_AR': '''Tablero:
    - Permite la creación de una página de inicio personalizada.
''',
    'description_es_CO': '''Escritorio:
    - Permite la creación de una página de inicio personalizada.
''',
    'description_es_ES': '''Escritorio:
    - Permite la creación de una página de inicio personalizada.
''',
    'description_fr_FR': '''Tableau de bord
    - Permet de créer un tableau de bord personalisé.
''',
    'description_nl_NL': '''Prikbord:
    - Maakt een persoonlijk prikbord mogelijk.
''',
    'description_ru_RU': '''Информационная панель:
    - позволяет создавать персональные панели.
''',
    'depends': [
        'ir',
        'res',
    ],
    'xml': [
        'dashboard.xml',
        'res.xml',
        'ir.xml',
    ],
    'translation': [
        'locale/bg_BG.po',
        'locale/ca_ES.po',
        'locale/cs_CZ.po',
        'locale/de_DE.po',
        'locale/es_AR.po',
        'locale/es_CO.po',
        'locale/es_ES.po',
        'locale/fr_FR.po',
        'locale/nl_NL.po',
        'locale/ru_RU.po',
    ],
}
